"""Helper classes for using auto-generated API."""
# pylint: disable=line-too-long too-many-instance-attributes too-many-public-methods

import asyncio
import json
import logging
import re
from datetime import time
from threading import Thread
from types import SimpleNamespace

from aiohttp import ClientSession
from aiohttp.client_exceptions import ClientConnectorError
from inflection import underscore
from mozart_api.api.mozart_api import MozartApi
from mozart_api.api_client import ApiClient
from mozart_api.configuration import Configuration

RECONNECT_INTERVAL: float = 15.0
WEBSOCKET_HEARTBEAT: float = 10
WEBSOCKET_RECIEVE_TIMEOUT: float = 5.0

logger = logging.getLogger(__name__)


def refactor_name(notification_type: str) -> str:
    """Remove WebSocketEvent prefix from string and convert to snake_case."""
    return underscore(notification_type.removeprefix("WebSocketEvent"))


def time_to_seconds(time_object: time) -> int:
    """Convert time object to number of seconds."""
    return (time_object.hour * 60 * 60) + (time_object.minute * 60) + time_object.second


def check_valid_jid(jid: str) -> bool:
    """Check if a JID is valid."""
    pattern = re.compile(r"(^\d{4})[.](\d{7})[.](\d{8})(@products\.bang-olufsen\.com)$")

    if pattern.fullmatch(jid) is not None:
        return True

    return False


class MozartClient(MozartApi):
    """User friendly setup for a Mozart device."""

    def __init__(
        self,
        host: str,
        websocket_reconnect: bool = False,
        websocket_reconnect_interval: float = RECONNECT_INTERVAL,
    ) -> None:
        """Initialize Mozart device."""
        self.host: str = host
        self.websocket_connected: bool = False
        self.websocket_reconnect: bool = websocket_reconnect
        self._websocket_reconnect_interval: float = websocket_reconnect_interval

        self._websocket_threads: set[Thread] = set()
        self._websocket_active: bool = False

        self._on_connection_lost = None
        self._on_connection = None

        self._on_all_notifications = None
        self._on_all_notifications_raw = None

        self._on_active_hdmi_input_signal_notification = None
        self._on_active_listening_mode_notification = None
        self._on_active_speaker_group_notification = None
        self._on_alarm_timer_notification = None
        self._on_alarm_triggered_notification = None
        self._on_battery_notification = None
        self._on_beo_remote_button_notification = None
        self._on_beolink_experiences_result_notification = None
        self._on_beolink_join_result_notification = None
        self._on_button_notification = None
        self._on_curtains_notification = None
        self._on_hdmi_video_format_signal_notification = None
        self._on_notification_notification = None
        self._on_playback_error_notification = None
        self._on_playback_metadata_notification = None
        self._on_playback_progress_notification = None
        self._on_playback_source_notification = None
        self._on_playback_state_notification = None
        self._on_power_state_notification = None
        self._on_puc_install_remote_id_status_notification = None
        self._on_role_notification = None
        self._on_room_compensation_current_measurement_event_notification = None
        self._on_room_compensation_state_notification = None
        self._on_software_update_state_notification = None
        self._on_sound_settings_notification = None
        self._on_source_change_notification = None
        self._on_speaker_group_changed_notification = None
        self._on_stand_connected_notification = None
        self._on_stand_position_notification = None
        self._on_tv_info_notification = None
        self._on_volume_notification = None
        self._on_wisa_out_state_notification = None

        # Configure MozartApi object.
        configuration = Configuration(host=self.host)
        configuration.verify_ssl = False

        super().__init__(ApiClient(configuration))

    def connect_notifications(self, remote_control=False) -> None:
        """Start the WebSocket listener thread."""
        if self._websocket_active:
            # Check if only the remote control listener should be started
            if len(self._websocket_threads) == 1 and remote_control is True:
                pass
            else:
                logger.warning("WebSocket listener(s) already running")
                return

        else:
            self._websocket_active = True

            # Always add main WebSocket listener
            self._websocket_threads.add(
                Thread(
                    name=f"{self.host} - listener thread",
                    target=self._start_websocket_listener,
                    args=(f"ws://{self.host}:9339/",),
                )
            )

        # Add WebSocket listener for remote control events if defined.
        if remote_control:
            self._websocket_threads.add(
                Thread(
                    name=f"{self.host} - remote listener thread",
                    target=self._start_websocket_listener,
                    args=(f"ws://{self.host}:9339/remoteControl",),
                )
            )

        for websocket_thread in self._websocket_threads:
            if websocket_thread.is_alive():
                continue
            websocket_thread.start()

    def disconnect_notifications(self) -> None:
        """Stop the WebSocket listener threads. May take a few seconds to complete, non-blocking."""
        # Don't try to close the WebSocket listener(s) if already closed
        if not self._websocket_active:
            logger.warning("WebSocket listener(s) already closed")
            return

        self._websocket_active = False

        # Start a new thread to kill the threads with blocking code
        Thread(
            name=f"{self.host} - websocket listener closer",
            target=self._stop_websocket_listeners,
        ).start()

    def _stop_websocket_listeners(self) -> None:
        """Stop running blocking threads."""
        for websocket_thread in self._websocket_threads:
            websocket_thread.join()

        self.websocket_connected = False
        self._websocket_threads = set()

    def _start_websocket_listener(self, host: str) -> None:
        """Start the async WebSocket listener."""
        asyncio.run(self._websocket_listener(host))

    async def _websocket_listener(self, host: str) -> None:
        """WebSocket listener."""
        while True:
            try:
                async with ClientSession() as session:
                    async with session.ws_connect(
                        url=host, heartbeat=WEBSOCKET_RECIEVE_TIMEOUT
                    ) as websocket:
                        self.websocket_connected = True

                        if self._on_connection:
                            self._on_connection()

                        while self._websocket_active:
                            # Receive JSON in order to get the Websocket notification name for deserialization
                            try:
                                notification = await asyncio.wait_for(
                                    websocket.receive_json(),
                                    timeout=WEBSOCKET_RECIEVE_TIMEOUT,
                                )

                                # Ensure that any notifications received after the disconnect command has been executed are not processed
                                if not self._websocket_active:
                                    break

                                self._on_message(notification)
                            except asyncio.TimeoutError:
                                pass

                        return

            except (ClientConnectorError, TypeError) as error:
                if self.websocket_connected:
                    self.websocket_connected = False

                    if self._on_connection_lost:
                        self._on_connection_lost()

                if not self.websocket_reconnect:
                    logger.error("%s : %s", host, error)
                    return

                await asyncio.sleep(self._websocket_reconnect_interval)

    def _on_message(self, notification) -> None:
        """Handle WebSocket notifications."""

        # Get the object type and deserialized object.
        try:
            notification_type = notification["eventType"]

            deserialized_data = self.api_client.deserialize(
                SimpleNamespace(data=json.dumps(notification)), notification_type
            ).event_data

            refactored_type = refactor_name(notification_type)

        except (ValueError, AttributeError) as error:
            logger.error(
                "Error deserializing WebSocket notification %s error %s",
                notification_type,
                error,
            )
            return

        # Ensure that only valid notifications trigger callbacks
        if deserialized_data is None:
            return

        # Handle all notifications if defined
        if self._on_all_notifications:
            self._on_all_notifications(deserialized_data, refactored_type)

        if self._on_all_notifications_raw:
            self._on_all_notifications_raw(notification)

        # Handle specific notifications if defined
        {
            "WebSocketEventActiveHdmiInputSignal": lambda notification: self._on_active_hdmi_input_signal_notification(
                notification
            )
            if self._on_active_hdmi_input_signal_notification
            else None,
            "WebSocketEventActiveListeningMode": lambda notification: self._on_active_listening_mode_notification(
                notification
            )
            if self._on_active_listening_mode_notification
            else None,
            "WebSocketEventActiveSpeakerGroup": lambda notification: self._on_active_speaker_group_notification(
                notification
            )
            if self._on_active_speaker_group_notification
            else None,
            "WebSocketEventAlarmTimer": lambda notification: self._on_alarm_timer_notification(
                notification
            )
            if self._on_alarm_timer_notification
            else None,
            "WebSocketEventAlarmTriggered": lambda notification: self._on_alarm_triggered_notification(
                notification
            )
            if self._on_alarm_triggered_notification
            else None,
            "WebSocketEventBattery": lambda notification: self._on_battery_notification(
                notification
            )
            if self._on_battery_notification
            else None,
            "WebSocketEventBeoRemoteButton": lambda notification: self._on_beo_remote_button_notification(
                notification
            )
            if self._on_beo_remote_button_notification
            else None,
            "WebSocketEventBeolinkExperiencesResult": lambda notification: self._on_beolink_experiences_result_notification(
                notification
            )
            if self._on_beolink_experiences_result_notification
            else None,
            "WebSocketEventBeolinkJoinResult": lambda notification: self._on_beolink_join_result_notification(
                notification
            )
            if self._on_beolink_join_result_notification
            else None,
            "WebSocketEventButton": lambda notification: self._on_button_notification(
                notification
            )
            if self._on_button_notification
            else None,
            "WebSocketEventCurtains": lambda notification: self._on_curtains_notification(
                notification
            )
            if self._on_curtains_notification
            else None,
            "WebSocketEventHdmiVideoFormatSignal": lambda notification: self._on_hdmi_video_format_signal_notification(
                notification
            )
            if self._on_hdmi_video_format_signal_notification
            else None,
            "WebSocketEventNotification": lambda notification: self._on_notification_notification(
                notification
            )
            if self._on_notification_notification
            else None,
            "WebSocketEventPlaybackError": lambda notification: self._on_playback_error_notification(
                notification
            )
            if self._on_playback_error_notification
            else None,
            "WebSocketEventPlaybackMetadata": lambda notification: self._on_playback_metadata_notification(
                notification
            )
            if self._on_playback_metadata_notification
            else None,
            "WebSocketEventPlaybackProgress": lambda notification: self._on_playback_progress_notification(
                notification
            )
            if self._on_playback_progress_notification
            else None,
            "WebSocketEventPlaybackSource": lambda notification: self._on_playback_source_notification(
                notification
            )
            if self._on_playback_source_notification
            else None,
            "WebSocketEventPlaybackState": lambda notification: self._on_playback_state_notification(
                notification
            )
            if self._on_playback_state_notification
            else None,
            "WebSocketEventPowerState": lambda notification: self._on_power_state_notification(
                notification
            )
            if self._on_power_state_notification
            else None,
            "WebSocketEventPucInstallRemoteIdStatus": lambda notification: self._on_puc_install_remote_id_status_notification(
                notification
            )
            if self._on_puc_install_remote_id_status_notification
            else None,
            "WebSocketEventRole": lambda notification: self._on_role_notification(
                notification
            )
            if self._on_role_notification
            else None,
            "WebSocketEventRoomCompensationCurrentMeasurementEvent": lambda notification: self._on_room_compensation_current_measurement_event_notification(
                notification
            )
            if self._on_room_compensation_current_measurement_event_notification
            else None,
            "WebSocketEventRoomCompensationState": lambda notification: self._on_room_compensation_state_notification(
                notification
            )
            if self._on_room_compensation_state_notification
            else None,
            "WebSocketEventSoftwareUpdateState": lambda notification: self._on_software_update_state_notification(
                notification
            )
            if self._on_software_update_state_notification
            else None,
            "WebSocketEventSoundSettings": lambda notification: self._on_sound_settings_notification(
                notification
            )
            if self._on_sound_settings_notification
            else None,
            "WebSocketEventSourceChange": lambda notification: self._on_source_change_notification(
                notification
            )
            if self._on_source_change_notification
            else None,
            "WebSocketEventSpeakerGroupChanged": lambda notification: self._on_speaker_group_changed_notification(
                notification
            )
            if self._on_speaker_group_changed_notification
            else None,
            "WebSocketEventStandConnected": lambda notification: self._on_stand_connected_notification(
                notification
            )
            if self._on_stand_connected_notification
            else None,
            "WebSocketEventStandPosition": lambda notification: self._on_stand_position_notification(
                notification
            )
            if self._on_stand_position_notification
            else None,
            "WebSocketEventTvInfo": lambda notification: self._on_tv_info_notification(
                notification
            )
            if self._on_tv_info_notification
            else None,
            "WebSocketEventVolume": lambda notification: self._on_volume_notification(
                notification
            )
            if self._on_volume_notification
            else None,
            "WebSocketEventWisaOutState": lambda notification: self._on_wisa_out_state_notification(
                notification
            )
            if self._on_wisa_out_state_notification
            else None,
        }[notification_type](deserialized_data)

    def get_on_connection_lost(self, on_connection_lost) -> None:
        """Callback for WebSocket connection lost."""
        self._on_connection_lost = on_connection_lost

    def get_on_connection(self, on_connection) -> None:
        """Callback for WebSocket connection."""
        self._on_connection = on_connection

    def get_all_notifications(self, on_all_notifications) -> None:
        """Callback for all notifications."""
        self._on_all_notifications = on_all_notifications

    def get_all_notifications_raw(self, on_all_notifications_raw) -> None:
        """Callback for all notifications as dict."""
        self._on_all_notifications_raw = on_all_notifications_raw

    def get_active_hdmi_input_signal_notifications(
        self, on_active_hdmi_input_signal_notification
    ) -> None:
        """Callback for WebSocketEventActiveHdmiInputSignal notifications."""
        self._on_active_hdmi_input_signal_notification = (
            on_active_hdmi_input_signal_notification
        )

    def get_active_listening_mode_notifications(
        self, on_active_listening_mode_notification
    ) -> None:
        """Callback for WebSocketEventActiveListeningMode notifications."""
        self._on_active_listening_mode_notification = (
            on_active_listening_mode_notification
        )

    def get_active_speaker_group_notifications(
        self, on_active_speaker_group_notification
    ) -> None:
        """Callback for WebSocketEventActiveSpeakerGroup notifications."""
        self._on_active_speaker_group_notification = (
            on_active_speaker_group_notification
        )

    def get_alarm_timer_notifications(self, on_alarm_timer_notification) -> None:
        """Callback for WebSocketEventAlarmTimer notifications."""
        self._on_alarm_timer_notification = on_alarm_timer_notification

    def get_alarm_triggered_notifications(
        self, on_alarm_triggered_notification
    ) -> None:
        """Callback for WebSocketEventAlarmTriggered notifications."""
        self._on_alarm_triggered_notification = on_alarm_triggered_notification

    def get_battery_notifications(self, on_battery_notification) -> None:
        """Callback for WebSocketEventBattery notifications."""
        self._on_battery_notification = on_battery_notification

    def get_beo_remote_button_notifications(
        self, on_beo_remote_button_notification
    ) -> None:
        """Callback for WebSocketEventBeoRemoteButton notifications."""
        self._on_beo_remote_button_notification = on_beo_remote_button_notification

    def get_beolink_experiences_result_notifications(
        self, on_beolink_experiences_result_notification
    ) -> None:
        """Callback for WebSocketEventBeolinkExperiencesResult notifications."""
        self._on_beolink_experiences_result_notification = (
            on_beolink_experiences_result_notification
        )

    def get_beolink_join_result_notifications(
        self, on_beolink_join_result_notification
    ) -> None:
        """Callback for WebSocketEventBeolinkJoinResult notifications."""
        self._on_beolink_join_result_notification = on_beolink_join_result_notification

    def get_button_notifications(self, on_button_notification) -> None:
        """Callback for WebSocketEventButton notifications."""
        self._on_button_notification = on_button_notification

    def get_curtains_notifications(self, on_curtains_notification) -> None:
        """Callback for WebSocketEventCurtains notifications."""
        self._on_curtains_notification = on_curtains_notification

    def get_hdmi_video_format_signal_notifications(
        self, on_hdmi_video_format_signal_notification
    ) -> None:
        """Callback for WebSocketEventHdmiVideoFormatSignal notifications."""
        self._on_hdmi_video_format_signal_notification = (
            on_hdmi_video_format_signal_notification
        )

    def get_notification_notifications(self, on_notification_notification) -> None:
        """Callback for WebSocketEventNotification notifications."""
        self._on_notification_notification = on_notification_notification

    def get_playback_error_notifications(self, on_playback_error_notification) -> None:
        """Callback for WebSocketEventPlaybackError notifications."""
        self._on_playback_error_notification = on_playback_error_notification

    def get_playback_metadata_notifications(
        self, on_playback_metadata_notification
    ) -> None:
        """Callback for WebSocketEventPlaybackMetadata notifications."""
        self._on_playback_metadata_notification = on_playback_metadata_notification

    def get_playback_progress_notifications(
        self, on_playback_progress_notification
    ) -> None:
        """Callback for WebSocketEventPlaybackProgress notifications."""
        self._on_playback_progress_notification = on_playback_progress_notification

    def get_playback_source_notifications(
        self, on_playback_source_notification
    ) -> None:
        """Callback for WebSocketEventPlaybackSource notifications."""
        self._on_playback_source_notification = on_playback_source_notification

    def get_playback_state_notifications(self, on_playback_state_notification) -> None:
        """Callback for WebSocketEventPlaybackState notifications."""
        self._on_playback_state_notification = on_playback_state_notification

    def get_power_state_notifications(self, on_power_state_notification) -> None:
        """Callback for WebSocketEventPowerState notifications."""
        self._on_power_state_notification = on_power_state_notification

    def get_puc_install_remote_id_status_notifications(
        self, on_puc_install_remote_id_status_notification
    ) -> None:
        """Callback for WebSocketEventPucInstallRemoteIdStatus notifications."""
        self._on_puc_install_remote_id_status_notification = (
            on_puc_install_remote_id_status_notification
        )

    def get_role_notifications(self, on_role_notification) -> None:
        """Callback for WebSocketEventRole notifications."""
        self._on_role_notification = on_role_notification

    def get_room_compensation_current_measurement_event_notifications(
        self, on_room_compensation_current_measurement_event_notification
    ) -> None:
        """Callback for WebSocketEventRoomCompensationCurrentMeasurementEvent notifications."""
        self._on_room_compensation_current_measurement_event_notification = (
            on_room_compensation_current_measurement_event_notification
        )

    def get_room_compensation_state_notifications(
        self, on_room_compensation_state_notification
    ) -> None:
        """Callback for WebSocketEventRoomCompensationState notifications."""
        self._on_room_compensation_state_notification = (
            on_room_compensation_state_notification
        )

    def get_software_update_state_notifications(
        self, on_software_update_state_notification
    ) -> None:
        """Callback for WebSocketEventSoftwareUpdateState notifications."""
        self._on_software_update_state_notification = (
            on_software_update_state_notification
        )

    def get_sound_settings_notifications(self, on_sound_settings_notification) -> None:
        """Callback for WebSocketEventSoundSettings notifications."""
        self._on_sound_settings_notification = on_sound_settings_notification

    def get_source_change_notifications(self, on_source_change_notification) -> None:
        """Callback for WebSocketEventSourceChange notifications."""
        self._on_source_change_notification = on_source_change_notification

    def get_speaker_group_changed_notifications(
        self, on_speaker_group_changed_notification
    ) -> None:
        """Callback for WebSocketEventSpeakerGroupChanged notifications."""
        self._on_speaker_group_changed_notification = (
            on_speaker_group_changed_notification
        )

    def get_stand_connected_notifications(
        self, on_stand_connected_notification
    ) -> None:
        """Callback for WebSocketEventStandConnected notifications."""
        self._on_stand_connected_notification = on_stand_connected_notification

    def get_stand_position_notifications(self, on_stand_position_notification) -> None:
        """Callback for WebSocketEventStandPosition notifications."""
        self._on_stand_position_notification = on_stand_position_notification

    def get_tv_info_notifications(self, on_tv_info_notification) -> None:
        """Callback for WebSocketEventTvInfo notifications."""
        self._on_tv_info_notification = on_tv_info_notification

    def get_volume_notifications(self, on_volume_notification) -> None:
        """Callback for WebSocketEventVolume notifications."""
        self._on_volume_notification = on_volume_notification

    def get_wisa_out_state_notifications(self, on_wisa_out_state_notification) -> None:
        """Callback for WebSocketEventWisaOutState notifications."""
        self._on_wisa_out_state_notification = on_wisa_out_state_notification



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import mozart_api
from mozart_api.models.overlay_play_request_text_to_speech import (
    OverlayPlayRequestTextToSpeech,
)  # noqa: E501
from mozart_api.rest import ApiException


class TestOverlayPlayRequestTextToSpeech(unittest.TestCase):
    """OverlayPlayRequestTextToSpeech unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test OverlayPlayRequestTextToSpeech
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # model = mozart_api.models.overlay_play_request_text_to_speech.OverlayPlayRequestTextToSpeech()  # noqa: E501
        if include_optional:
            return OverlayPlayRequestTextToSpeech(
                text_to_speech=mozart_api.models.overlay_play_request_text_to_speech_text_to_speech.OverlayPlayRequestTextToSpeech_textToSpeech(
                    lang="en-us",
                    text="0",
                )
            )
        else:
            return OverlayPlayRequestTextToSpeech()

    def testOverlayPlayRequestTextToSpeech(self):
        """Test OverlayPlayRequestTextToSpeech"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from datetime import datetime
from typing import List, Dict, Literal, Optional


from mozart_api.configuration import Configuration


class SoundAdjustments(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "ambience": "float",
        "bass": "int",
        "directivity": "str",
        "eco_mode": "bool",
        "fadein": "bool",
        "loudness": "bool",
        "treble": "int",
    }

    attribute_map = {
        "ambience": "ambience",
        "bass": "bass",
        "directivity": "directivity",
        "eco_mode": "ecoMode",
        "fadein": "fadein",
        "loudness": "loudness",
        "treble": "treble",
    }

    def __init__(
        self,
        ambience: Optional[float] = None,
        bass: Optional[int] = None,
        directivity: Optional[str] = None,
        eco_mode: Optional[bool] = None,
        fadein: Optional[bool] = None,
        loudness: Optional[bool] = None,
        treble: Optional[int] = None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """SoundAdjustments - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._ambience = None
        self._bass = None
        self._directivity = None
        self._eco_mode = None
        self._fadein = None
        self._loudness = None
        self._treble = None
        self.discriminator = None

        if ambience is not None:
            self.ambience = ambience
        if bass is not None:
            self.bass = bass
        if directivity is not None:
            self.directivity = directivity
        if eco_mode is not None:
            self.eco_mode = eco_mode
        if fadein is not None:
            self.fadein = fadein
        if loudness is not None:
            self.loudness = loudness
        if treble is not None:
            self.treble = treble

    @property
    def ambience(self):
        # type: () -> float
        """Gets the ambience of this SoundAdjustments.  # noqa: E501


        :return: The ambience of this SoundAdjustments.  # noqa: E501
        :rtype: float
        """
        return self._ambience

    @ambience.setter
    def ambience(self, ambience):
        # type: (float) -> None
        """Sets the ambience of this SoundAdjustments.


        :param ambience: The ambience of this SoundAdjustments.  # noqa: E501
        :type ambience: float
        :rtype: None
        """

        self._ambience = ambience

    @property
    def bass(self):
        # type: () -> int
        """Gets the bass of this SoundAdjustments.  # noqa: E501


        :return: The bass of this SoundAdjustments.  # noqa: E501
        :rtype: int
        """
        return self._bass

    @bass.setter
    def bass(self, bass):
        # type: (int) -> None
        """Sets the bass of this SoundAdjustments.


        :param bass: The bass of this SoundAdjustments.  # noqa: E501
        :type bass: int
        :rtype: None
        """

        self._bass = bass

    @property
    def directivity(self):
        # type: () -> str
        """Gets the directivity of this SoundAdjustments.  # noqa: E501


        :return: The directivity of this SoundAdjustments.  # noqa: E501
        :rtype: str
        """
        return self._directivity

    @directivity.setter
    def directivity(self, directivity):
        # type: (str) -> None
        """Sets the directivity of this SoundAdjustments.


        :param directivity: The directivity of this SoundAdjustments.  # noqa: E501
        :type directivity: str
        :rtype: None
        """

        self._directivity = directivity

    @property
    def eco_mode(self):
        # type: () -> bool
        """Gets the eco_mode of this SoundAdjustments.  # noqa: E501


        :return: The eco_mode of this SoundAdjustments.  # noqa: E501
        :rtype: bool
        """
        return self._eco_mode

    @eco_mode.setter
    def eco_mode(self, eco_mode):
        # type: (bool) -> None
        """Sets the eco_mode of this SoundAdjustments.


        :param eco_mode: The eco_mode of this SoundAdjustments.  # noqa: E501
        :type eco_mode: bool
        :rtype: None
        """

        self._eco_mode = eco_mode

    @property
    def fadein(self):
        # type: () -> bool
        """Gets the fadein of this SoundAdjustments.  # noqa: E501


        :return: The fadein of this SoundAdjustments.  # noqa: E501
        :rtype: bool
        """
        return self._fadein

    @fadein.setter
    def fadein(self, fadein):
        # type: (bool) -> None
        """Sets the fadein of this SoundAdjustments.


        :param fadein: The fadein of this SoundAdjustments.  # noqa: E501
        :type fadein: bool
        :rtype: None
        """

        self._fadein = fadein

    @property
    def loudness(self):
        # type: () -> bool
        """Gets the loudness of this SoundAdjustments.  # noqa: E501


        :return: The loudness of this SoundAdjustments.  # noqa: E501
        :rtype: bool
        """
        return self._loudness

    @loudness.setter
    def loudness(self, loudness):
        # type: (bool) -> None
        """Sets the loudness of this SoundAdjustments.


        :param loudness: The loudness of this SoundAdjustments.  # noqa: E501
        :type loudness: bool
        :rtype: None
        """

        self._loudness = loudness

    @property
    def treble(self):
        # type: () -> int
        """Gets the treble of this SoundAdjustments.  # noqa: E501


        :return: The treble of this SoundAdjustments.  # noqa: E501
        :rtype: int
        """
        return self._treble

    @treble.setter
    def treble(self, treble):
        # type: (int) -> None
        """Sets the treble of this SoundAdjustments.


        :param treble: The treble of this SoundAdjustments.  # noqa: E501
        :type treble: int
        :rtype: None
        """

        self._treble = treble

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SoundAdjustments):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SoundAdjustments):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import mozart_api
from mozart_api.models.web_socket_event_beolink_experiences_result import (
    WebSocketEventBeolinkExperiencesResult,
)  # noqa: E501
from mozart_api.rest import ApiException


class TestWebSocketEventBeolinkExperiencesResult(unittest.TestCase):
    """WebSocketEventBeolinkExperiencesResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test WebSocketEventBeolinkExperiencesResult
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # model = mozart_api.models.web_socket_event_beolink_experiences_result.WebSocketEventBeolinkExperiencesResult()  # noqa: E501
        if include_optional:
            return WebSocketEventBeolinkExperiencesResult(
                event_data=mozart_api.models.beolink_experiences_result.BeolinkExperiencesResult(
                    experiences=[
                        mozart_api.models.beolink_experience.BeolinkExperience(
                            category="TV",
                            id="0",
                            linkable=True,
                            name="0",
                            product_friendly_name="0",
                            source_friendly_name="0",
                            type="0",
                            unique_source_id="0",
                        )
                    ],
                    request_id="48985a4f-a4de-4b44-9757-c9a7407b8882",
                    status="ok",
                ),
                event_type="0",
            )
        else:
            return WebSocketEventBeolinkExperiencesResult(
                event_data=mozart_api.models.beolink_experiences_result.BeolinkExperiencesResult(
                    experiences=[
                        mozart_api.models.beolink_experience.BeolinkExperience(
                            category="TV",
                            id="0",
                            linkable=True,
                            name="0",
                            product_friendly_name="0",
                            source_friendly_name="0",
                            type="0",
                            unique_source_id="0",
                        )
                    ],
                    request_id="48985a4f-a4de-4b44-9757-c9a7407b8882",
                    status="ok",
                ),
                event_type="0",
            )

    def testWebSocketEventBeolinkExperiencesResult(self):
        """Test WebSocketEventBeolinkExperiencesResult"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mozart_api
from mozart_api.api.scenes_api import ScenesApi  # noqa: E501
from mozart_api.rest import ApiException


class TestScenesApi(unittest.TestCase):
    """ScenesApi unit test stubs"""

    def setUp(self):
        self.api = mozart_api.api.scenes_api.ScenesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_all_scenes(self):
        """Test case for get_all_scenes

        Get a list of configured scenes  # noqa: E501
        """
        pass

    def test_post_scene_match_trigger(self):
        """Test case for post_scene_match_trigger

        Trigger the first scene with same non null objects provided in the SceneMatch object  # noqa: E501
        """
        pass

    def test_post_scene_trigger(self):
        """Test case for post_scene_trigger

        Trigger a specific scene  # noqa: E501
        """
        pass

    def test_run_provided_scene(self):
        """Test case for run_provided_scene

        Run provided scene  # noqa: E501
        """
        pass


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from mozart_api.api_client import ApiClient
from mozart_api.exceptions import ApiTypeError, ApiValueError  # noqa: F401


class PlaybackApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def activate_preset(self, id, **kwargs):  # noqa: E501
        """Trigger a preset  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.activate_preset(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int id: the id of the preset you want to trigger (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.activate_preset_with_http_info(id, **kwargs)  # noqa: E501

    def activate_preset_with_http_info(self, id, **kwargs):  # noqa: E501
        """Trigger a preset  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.activate_preset_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int id: the id of the preset you want to trigger (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["id"]
        all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
            ]
        )

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method activate_preset" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and (
            "id" not in local_var_params or local_var_params["id"] is None  # noqa: E501
        ):  # noqa: E501
            raise ApiValueError(
                "Missing the required parameter `id` when calling `activate_preset`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "id" in local_var_params:
            path_params["id"] = local_var_params["id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            "/api/v1/playback/preset/{id}/trigger",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def add_to_queue(self, play_queue_item, **kwargs):  # noqa: E501
        """Add an element to the queue  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_to_queue(play_queue_item, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param PlayQueueItem play_queue_item: the queue element you want to add (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.add_to_queue_with_http_info(play_queue_item, **kwargs)  # noqa: E501

    def add_to_queue_with_http_info(self, play_queue_item, **kwargs):  # noqa: E501
        """Add an element to the queue  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_to_queue_with_http_info(play_queue_item, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param PlayQueueItem play_queue_item: the queue element you want to add (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["play_queue_item"]
        all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
            ]
        )

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_to_queue" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'play_queue_item' is set
        if self.api_client.client_side_validation and (
            "play_queue_item" not in local_var_params
            or local_var_params["play_queue_item"] is None  # noqa: E501
        ):  # noqa: E501
            raise ApiValueError(
                "Missing the required parameter `play_queue_item` when calling `add_to_queue`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "play_queue_item" in local_var_params:
            body_params = local_var_params["play_queue_item"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            "/api/v1/playback/queue",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def get_available_sources(self, **kwargs):  # noqa: E501
        """Get all the available sources  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_available_sources(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param bool target_remote: filter sources for remote control
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: SourceArray
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.get_available_sources_with_http_info(**kwargs)  # noqa: E501

    def get_available_sources_with_http_info(self, **kwargs):  # noqa: E501
        """Get all the available sources  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_available_sources_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param bool target_remote: filter sources for remote control
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(SourceArray, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["target_remote"]
        all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
            ]
        )

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_available_sources" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []
        if (
            "target_remote" in local_var_params
            and local_var_params["target_remote"] is not None
        ):  # noqa: E501
            query_params.append(
                ("target-remote", local_var_params["target_remote"])
            )  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            "/api/v1/playback/sources",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="SourceArray",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def get_playback_state(self, **kwargs):  # noqa: E501
        """Get the current playback state  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_playback_state(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: PlaybackState
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.get_playback_state_with_http_info(**kwargs)  # noqa: E501

    def get_playback_state_with_http_info(self, **kwargs):  # noqa: E501
        """Get the current playback state  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_playback_state_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(PlaybackState, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = []
        all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
            ]
        )

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_playback_state" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            "/api/v1/playback/state",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="PlaybackState",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def get_settings_queue(self, **kwargs):  # noqa: E501
        """Get the current queue settings  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_settings_queue(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: PlayQueueSettings
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.get_settings_queue_with_http_info(**kwargs)  # noqa: E501

    def get_settings_queue_with_http_info(self, **kwargs):  # noqa: E501
        """Get the current queue settings  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_settings_queue_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(PlayQueueSettings, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = []
        all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
            ]
        )

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_settings_queue" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            "/api/v1/playback/queue/settings",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="PlayQueueSettings",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def post_clear_queue(self, **kwargs):  # noqa: E501
        """Clear the queue  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_clear_queue(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.post_clear_queue_with_http_info(**kwargs)  # noqa: E501

    def post_clear_queue_with_http_info(self, **kwargs):  # noqa: E501
        """Clear the queue  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_clear_queue_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = []
        all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
            ]
        )

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_clear_queue" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            "/api/v1/playback/queue/clear",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def post_playback_command(self, command, **kwargs):  # noqa: E501
        """Send a specific playback command to the product  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_playback_command(command, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str command: the named command to execute (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.post_playback_command_with_http_info(
            command, **kwargs
        )  # noqa: E501

    def post_playback_command_with_http_info(self, command, **kwargs):  # noqa: E501
        """Send a specific playback command to the product  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_playback_command_with_http_info(command, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str command: the named command to execute (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["command"]
        all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
            ]
        )

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_playback_command" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'command' is set
        if self.api_client.client_side_validation and (
            "command" not in local_var_params
            or local_var_params["command"] is None  # noqa: E501
        ):  # noqa: E501
            raise ApiValueError(
                "Missing the required parameter `command` when calling `post_playback_command`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "command" in local_var_params:
            path_params["command"] = local_var_params["command"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            "/api/v1/playback/command/{command}",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def post_uri_source(self, uri, **kwargs):  # noqa: E501
        """Set the URI from which sound is streamed  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_uri_source(uri, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param Uri uri: the desired uri from which to stream data (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.post_uri_source_with_http_info(uri, **kwargs)  # noqa: E501

    def post_uri_source_with_http_info(self, uri, **kwargs):  # noqa: E501
        """Set the URI from which sound is streamed  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_uri_source_with_http_info(uri, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param Uri uri: the desired uri from which to stream data (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["uri"]
        all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
            ]
        )

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_uri_source" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'uri' is set
        if self.api_client.client_side_validation and (
            "uri" not in local_var_params
            or local_var_params["uri"] is None  # noqa: E501
        ):  # noqa: E501
            raise ApiValueError(
                "Missing the required parameter `uri` when calling `post_uri_source`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "uri" in local_var_params:
            body_params = local_var_params["uri"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            "/api/v1/playback/uri",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def seek_to_position(self, position_ms, **kwargs):  # noqa: E501
        """Seek to position in stream  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.seek_to_position(position_ms, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int position_ms: position in milliseconds (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.seek_to_position_with_http_info(position_ms, **kwargs)  # noqa: E501

    def seek_to_position_with_http_info(self, position_ms, **kwargs):  # noqa: E501
        """Seek to position in stream  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.seek_to_position_with_http_info(position_ms, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int position_ms: position in milliseconds (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["position_ms"]
        all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
            ]
        )

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method seek_to_position" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'position_ms' is set
        if self.api_client.client_side_validation and (
            "position_ms" not in local_var_params
            or local_var_params["position_ms"] is None  # noqa: E501
        ):  # noqa: E501
            raise ApiValueError(
                "Missing the required parameter `position_ms` when calling `seek_to_position`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if (
            "position_ms" in local_var_params
            and local_var_params["position_ms"] is not None
        ):  # noqa: E501
            query_params.append(
                ("position_ms", local_var_params["position_ms"])
            )  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            "/api/v1/playback/seek",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def set_active_source(self, source_id, **kwargs):  # noqa: E501
        """Set the active source  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_active_source(source_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str source_id: the id of the source to activate (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.set_active_source_with_http_info(source_id, **kwargs)  # noqa: E501

    def set_active_source_with_http_info(self, source_id, **kwargs):  # noqa: E501
        """Set the active source  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_active_source_with_http_info(source_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str source_id: the id of the source to activate (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["source_id"]
        all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
            ]
        )

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method set_active_source" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'source_id' is set
        if self.api_client.client_side_validation and (
            "source_id" not in local_var_params
            or local_var_params["source_id"] is None  # noqa: E501
        ):  # noqa: E501
            raise ApiValueError(
                "Missing the required parameter `source_id` when calling `set_active_source`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "source_id" in local_var_params:
            path_params["sourceId"] = local_var_params["source_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            "/api/v1/playback/sources/active/{sourceId}",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def set_settings_queue(self, play_queue_settings, **kwargs):  # noqa: E501
        """Set queue settings  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_settings_queue(play_queue_settings, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param PlayQueueSettings play_queue_settings: the desired settings (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.set_settings_queue_with_http_info(
            play_queue_settings, **kwargs
        )  # noqa: E501

    def set_settings_queue_with_http_info(
        self, play_queue_settings, **kwargs
    ):  # noqa: E501
        """Set queue settings  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_settings_queue_with_http_info(play_queue_settings, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param PlayQueueSettings play_queue_settings: the desired settings (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["play_queue_settings"]
        all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
            ]
        )

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method set_settings_queue" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'play_queue_settings' is set
        if self.api_client.client_side_validation and (
            "play_queue_settings" not in local_var_params
            or local_var_params["play_queue_settings"] is None  # noqa: E501
        ):  # noqa: E501
            raise ApiValueError(
                "Missing the required parameter `play_queue_settings` when calling `set_settings_queue`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "play_queue_settings" in local_var_params:
            body_params = local_var_params["play_queue_settings"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            "/api/v1/playback/queue/settings",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def start_deezer_flow(self, **kwargs):  # noqa: E501
        """Play users flow. If no provided user id it will play the flow connected to the active account  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.start_deezer_flow(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UserFlow user_flow: Select user
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.start_deezer_flow_with_http_info(**kwargs)  # noqa: E501

    def start_deezer_flow_with_http_info(self, **kwargs):  # noqa: E501
        """Play users flow. If no provided user id it will play the flow connected to the active account  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.start_deezer_flow_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UserFlow user_flow: Select user
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["user_flow"]
        all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
            ]
        )

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method start_deezer_flow" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "user_flow" in local_var_params:
            body_params = local_var_params["user_flow"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            "/api/v1/playback/deezer/flow",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mozart_api
from mozart_api.api.beolink_api import BeolinkApi  # noqa: E501
from mozart_api.rest import ApiException


class TestBeolinkApi(unittest.TestCase):
    """BeolinkApi unit test stubs"""

    def setUp(self):
        self.api = mozart_api.api.beolink_api.BeolinkApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_beolink_available_listeners(self):
        """Test case for get_beolink_available_listeners

        Get available listeners  # noqa: E501
        """
        pass

    def test_get_beolink_join_result(self):
        """Test case for get_beolink_join_result

        Get Beolink join result, test-endpoint  # noqa: E501
        """
        pass

    def test_get_beolink_listeners(self):
        """Test case for get_beolink_listeners

        Get joined peers  # noqa: E501
        """
        pass

    def test_get_beolink_peers(self):
        """Test case for get_beolink_peers

        Get discovered peers  # noqa: E501
        """
        pass

    def test_get_beolink_self(self):
        """Test case for get_beolink_self

        Get information about this device  # noqa: E501
        """
        pass

    def test_join_beolink_peer(self):
        """Test case for join_beolink_peer

        Join multi-room experience  # noqa: E501
        """
        pass

    def test_join_latest_beolink_experience(self):
        """Test case for join_latest_beolink_experience

        Trigger touch to join  # noqa: E501
        """
        pass

    def test_post_beolink_allstandby(self):
        """Test case for post_beolink_allstandby

        Broadcast an all standby event to turn all Beolink devices off  # noqa: E501
        """
        pass

    def test_post_beolink_expand(self):
        """Test case for post_beolink_expand

        Expand the current active experience  # noqa: E501
        """
        pass

    def test_post_beolink_leave(self):
        """Test case for post_beolink_leave

        Leave the ongoing experience (disconnect this device from remote)  # noqa: E501
        """
        pass

    def test_post_beolink_unexpand(self):
        """Test case for post_beolink_unexpand

        Unexpand (disconnect) a device from the multiroom session  # noqa: E501
        """
        pass


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import mozart_api
from mozart_api.models.playback_content_metadata import (
    PlaybackContentMetadata,
)  # noqa: E501
from mozart_api.rest import ApiException


class TestPlaybackContentMetadata(unittest.TestCase):
    """PlaybackContentMetadata unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PlaybackContentMetadata
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # model = mozart_api.models.playback_content_metadata.PlaybackContentMetadata()  # noqa: E501
        if include_optional:
            return PlaybackContentMetadata(
                album_name="0",
                art=[
                    mozart_api.models.art.Art(
                        has_local_image=True,
                        key="0",
                        size="0",
                        type="0",
                        url="0",
                    )
                ],
                artist_name="0",
                bitdepth=56,
                bitrate=56,
                container_name="0",
                encoding="pcm",
                genre="0",
                id=56,
                input_channel_processing="dolbySurround",
                input_channels="0",
                organization="0",
                output_channel_processing="Direct",
                output_channels="0",
                queue_id="0",
                remote_leader=mozart_api.models.beolink_leader.BeolinkLeader(
                    friendly_name="0",
                    jid="2714.1200304.26451293@products.bang-olufsen.com",
                ),
                remote_source="0",
                samplerate=56,
                source="0",
                source_internal_id="0",
                title="0",
                total_duration=56,
                total_duration_seconds=56,
                track=56,
                track_count=56,
                uri="0",
            )
        else:
            return PlaybackContentMetadata()

    def testPlaybackContentMetadata(self):
        """Test PlaybackContentMetadata"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from datetime import datetime
from typing import List, Dict, Literal, Optional


from mozart_api.configuration import Configuration


class VideoPixelFormat(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "bitdepth": "str",
        "chroma_subsample": "str",
        "colorimetry": "str",
        "full_range": "bool",
    }

    attribute_map = {
        "bitdepth": "bitdepth",
        "chroma_subsample": "chromaSubsample",
        "colorimetry": "colorimetry",
        "full_range": "fullRange",
    }

    def __init__(
        self,
        bitdepth: Optional["VideoPixelFormat.LTypeBitdepth"] = None,
        chroma_subsample: Optional["VideoPixelFormat.LTypeChromaSubsample"] = None,
        colorimetry: Optional["VideoPixelFormat.LTypeColorimetry"] = None,
        full_range: Optional[bool] = None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """VideoPixelFormat - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._bitdepth = None
        self._chroma_subsample = None
        self._colorimetry = None
        self._full_range = None
        self.discriminator = None

        if bitdepth is not None:
            self.bitdepth = bitdepth
        if chroma_subsample is not None:
            self.chroma_subsample = chroma_subsample
        if colorimetry is not None:
            self.colorimetry = colorimetry
        if full_range is not None:
            self.full_range = full_range

    LTypeBitdepth = Literal["bit8", "bit10", "bit12"]

    @property
    def bitdepth(self):
        # type: () -> 'VideoPixelFormat.LTypeBitdepth'
        """Gets the bitdepth of this VideoPixelFormat.  # noqa: E501


        :return: The bitdepth of this VideoPixelFormat.  # noqa: E501
        :rtype: 'VideoPixelFormat.LTypeBitdepth'
        """
        return self._bitdepth

    @bitdepth.setter
    def bitdepth(self, bitdepth):
        # type: ('VideoPixelFormat.LTypeBitdepth') -> None
        """Sets the bitdepth of this VideoPixelFormat.


        :param bitdepth: The bitdepth of this VideoPixelFormat.  # noqa: E501
        :type bitdepth: 'VideoPixelFormat.LTypeBitdepth'
        :rtype: None
        """
        allowed_values = ["bit8", "bit10", "bit12"]  # noqa: E501
        if (
            self.local_vars_configuration.client_side_validation
            and bitdepth not in allowed_values
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `bitdepth` ({0}), must be one of {1}".format(  # noqa: E501
                    bitdepth, allowed_values
                )
            )

        self._bitdepth = bitdepth

    LTypeChromaSubsample = Literal["yCbCr444RGB", "yCbCr422", "yCbCr420"]

    @property
    def chroma_subsample(self):
        # type: () -> 'VideoPixelFormat.LTypeChromaSubsample'
        """Gets the chroma_subsample of this VideoPixelFormat.  # noqa: E501


        :return: The chroma_subsample of this VideoPixelFormat.  # noqa: E501
        :rtype: 'VideoPixelFormat.LTypeChromaSubsample'
        """
        return self._chroma_subsample

    @chroma_subsample.setter
    def chroma_subsample(self, chroma_subsample):
        # type: ('VideoPixelFormat.LTypeChromaSubsample') -> None
        """Sets the chroma_subsample of this VideoPixelFormat.


        :param chroma_subsample: The chroma_subsample of this VideoPixelFormat.  # noqa: E501
        :type chroma_subsample: 'VideoPixelFormat.LTypeChromaSubsample'
        :rtype: None
        """
        allowed_values = ["yCbCr444RGB", "yCbCr422", "yCbCr420"]  # noqa: E501
        if (
            self.local_vars_configuration.client_side_validation
            and chroma_subsample not in allowed_values
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `chroma_subsample` ({0}), must be one of {1}".format(  # noqa: E501
                    chroma_subsample, allowed_values
                )
            )

        self._chroma_subsample = chroma_subsample

    LTypeColorimetry = Literal[
        "rGB",
        "opRGB",
        "rGBP3D65",
        "rGBP3DCI",
        "rGB2020",
        "yCC601",
        "yCC709",
        "xvYCC601",
        "xvYCC709",
        "sYCC601",
        "opYCC601",
        "yCC2020NCL",
        "yCC2020NL",
    ]

    @property
    def colorimetry(self):
        # type: () -> 'VideoPixelFormat.LTypeColorimetry'
        """Gets the colorimetry of this VideoPixelFormat.  # noqa: E501


        :return: The colorimetry of this VideoPixelFormat.  # noqa: E501
        :rtype: 'VideoPixelFormat.LTypeColorimetry'
        """
        return self._colorimetry

    @colorimetry.setter
    def colorimetry(self, colorimetry):
        # type: ('VideoPixelFormat.LTypeColorimetry') -> None
        """Sets the colorimetry of this VideoPixelFormat.


        :param colorimetry: The colorimetry of this VideoPixelFormat.  # noqa: E501
        :type colorimetry: 'VideoPixelFormat.LTypeColorimetry'
        :rtype: None
        """
        allowed_values = [
            "rGB",
            "opRGB",
            "rGBP3D65",
            "rGBP3DCI",
            "rGB2020",
            "yCC601",
            "yCC709",
            "xvYCC601",
            "xvYCC709",
            "sYCC601",
            "opYCC601",
            "yCC2020NCL",
            "yCC2020NL",
        ]  # noqa: E501
        if (
            self.local_vars_configuration.client_side_validation
            and colorimetry not in allowed_values
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `colorimetry` ({0}), must be one of {1}".format(  # noqa: E501
                    colorimetry, allowed_values
                )
            )

        self._colorimetry = colorimetry

    @property
    def full_range(self):
        # type: () -> bool
        """Gets the full_range of this VideoPixelFormat.  # noqa: E501


        :return: The full_range of this VideoPixelFormat.  # noqa: E501
        :rtype: bool
        """
        return self._full_range

    @full_range.setter
    def full_range(self, full_range):
        # type: (bool) -> None
        """Sets the full_range of this VideoPixelFormat.


        :param full_range: The full_range of this VideoPixelFormat.  # noqa: E501
        :type full_range: bool
        :rtype: None
        """

        self._full_range = full_range

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VideoPixelFormat):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, VideoPixelFormat):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import mozart_api
from mozart_api.models.remote_menu_item_properties import (
    RemoteMenuItemProperties,
)  # noqa: E501
from mozart_api.rest import ApiException


class TestRemoteMenuItemProperties(unittest.TestCase):
    """RemoteMenuItemProperties unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test RemoteMenuItemProperties
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # model = mozart_api.models.remote_menu_item_properties.RemoteMenuItemProperties()  # noqa: E501
        if include_optional:
            return RemoteMenuItemProperties(
                action_list=[
                    {"type": "volume", "volumeLevel": 35},
                    {"radioStationId": "8779112938791514", "type": "radio"},
                    {"stopDuration": 1300, "type": "stop"},
                ],
                scene_list=["0"],
                disabled=True,
                dynamic_list="none",
                first_child_menu_item_id="0",
                label="0",
                next_sibling_menu_item_id="0",
                parent_menu_item_id="0",
            )
        else:
            return RemoteMenuItemProperties()

    def testRemoteMenuItemProperties(self):
        """Test RemoteMenuItemProperties"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from datetime import datetime
from typing import List, Dict, Literal, Optional


from mozart_api.configuration import Configuration


class PlayQueueSettings(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "consume": "bool",
        "gapless": "bool",
        "repeat": "str",
        "shuffle": "bool",
    }

    attribute_map = {
        "consume": "consume",
        "gapless": "gapless",
        "repeat": "repeat",
        "shuffle": "shuffle",
    }

    def __init__(
        self,
        consume: Optional[bool] = None,
        gapless: Optional[bool] = None,
        repeat: Optional["PlayQueueSettings.LTypeRepeat"] = None,
        shuffle: Optional[bool] = None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """PlayQueueSettings - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._consume = None
        self._gapless = None
        self._repeat = None
        self._shuffle = None
        self.discriminator = None

        if consume is not None:
            self.consume = consume
        if gapless is not None:
            self.gapless = gapless
        if repeat is not None:
            self.repeat = repeat
        if shuffle is not None:
            self.shuffle = shuffle

    @property
    def consume(self):
        # type: () -> bool
        """Gets the consume of this PlayQueueSettings.  # noqa: E501


        :return: The consume of this PlayQueueSettings.  # noqa: E501
        :rtype: bool
        """
        return self._consume

    @consume.setter
    def consume(self, consume):
        # type: (bool) -> None
        """Sets the consume of this PlayQueueSettings.


        :param consume: The consume of this PlayQueueSettings.  # noqa: E501
        :type consume: bool
        :rtype: None
        """

        self._consume = consume

    @property
    def gapless(self):
        # type: () -> bool
        """Gets the gapless of this PlayQueueSettings.  # noqa: E501


        :return: The gapless of this PlayQueueSettings.  # noqa: E501
        :rtype: bool
        """
        return self._gapless

    @gapless.setter
    def gapless(self, gapless):
        # type: (bool) -> None
        """Sets the gapless of this PlayQueueSettings.


        :param gapless: The gapless of this PlayQueueSettings.  # noqa: E501
        :type gapless: bool
        :rtype: None
        """

        self._gapless = gapless

    LTypeRepeat = Literal["all", "track", "none"]

    @property
    def repeat(self):
        # type: () -> 'PlayQueueSettings.LTypeRepeat'
        """Gets the repeat of this PlayQueueSettings.  # noqa: E501


        :return: The repeat of this PlayQueueSettings.  # noqa: E501
        :rtype: 'PlayQueueSettings.LTypeRepeat'
        """
        return self._repeat

    @repeat.setter
    def repeat(self, repeat):
        # type: ('PlayQueueSettings.LTypeRepeat') -> None
        """Sets the repeat of this PlayQueueSettings.


        :param repeat: The repeat of this PlayQueueSettings.  # noqa: E501
        :type repeat: 'PlayQueueSettings.LTypeRepeat'
        :rtype: None
        """
        allowed_values = ["all", "track", "none"]  # noqa: E501
        if (
            self.local_vars_configuration.client_side_validation
            and repeat not in allowed_values
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `repeat` ({0}), must be one of {1}".format(  # noqa: E501
                    repeat, allowed_values
                )
            )

        self._repeat = repeat

    @property
    def shuffle(self):
        # type: () -> bool
        """Gets the shuffle of this PlayQueueSettings.  # noqa: E501


        :return: The shuffle of this PlayQueueSettings.  # noqa: E501
        :rtype: bool
        """
        return self._shuffle

    @shuffle.setter
    def shuffle(self, shuffle):
        # type: (bool) -> None
        """Sets the shuffle of this PlayQueueSettings.


        :param shuffle: The shuffle of this PlayQueueSettings.  # noqa: E501
        :type shuffle: bool
        :rtype: None
        """

        self._shuffle = shuffle

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PlayQueueSettings):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PlayQueueSettings):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from datetime import datetime
from typing import List, Dict, Literal, Optional

from mozart_api.models.room_compensation_version import RoomCompensationVersion
from mozart_api.models.room_compensation_result import RoomCompensationResult
from mozart_api.models.room_compensation_type import RoomCompensationType
from mozart_api.models.room_compensation_state import RoomCompensationState
from mozart_api.models.room_compensation_enabled import RoomCompensationEnabled
from mozart_api.models.room_compensation_debug import RoomCompensationDebug

from mozart_api.configuration import Configuration


class RoomCompensationInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "debug": "RoomCompensationDebug",
        "enabled": "RoomCompensationEnabled",
        "last_result": "RoomCompensationResult",
        "last_run": "RoomCompensationState",
        "type": "RoomCompensationType",
        "version": "RoomCompensationVersion",
    }

    attribute_map = {
        "debug": "debug",
        "enabled": "enabled",
        "last_result": "lastResult",
        "last_run": "lastRun",
        "type": "type",
        "version": "version",
    }

    def __init__(
        self,
        debug: Optional[RoomCompensationDebug] = None,
        enabled: Optional[RoomCompensationEnabled] = None,
        last_result: Optional[RoomCompensationResult] = None,
        last_run: Optional[RoomCompensationState] = None,
        type: Optional[RoomCompensationType] = None,
        version: Optional[RoomCompensationVersion] = None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """RoomCompensationInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._debug = None
        self._enabled = None
        self._last_result = None
        self._last_run = None
        self._type = None
        self._version = None
        self.discriminator = None

        if debug is not None:
            self.debug = debug
        if enabled is not None:
            self.enabled = enabled
        if last_result is not None:
            self.last_result = last_result
        if last_run is not None:
            self.last_run = last_run
        if type is not None:
            self.type = type
        if version is not None:
            self.version = version

    @property
    def debug(self):
        # type: () -> RoomCompensationDebug
        """Gets the debug of this RoomCompensationInfo.  # noqa: E501


        :return: The debug of this RoomCompensationInfo.  # noqa: E501
        :rtype: RoomCompensationDebug
        """
        return self._debug

    @debug.setter
    def debug(self, debug):
        # type: (RoomCompensationDebug) -> None
        """Sets the debug of this RoomCompensationInfo.


        :param debug: The debug of this RoomCompensationInfo.  # noqa: E501
        :type debug: RoomCompensationDebug
        :rtype: None
        """

        self._debug = debug

    @property
    def enabled(self):
        # type: () -> RoomCompensationEnabled
        """Gets the enabled of this RoomCompensationInfo.  # noqa: E501


        :return: The enabled of this RoomCompensationInfo.  # noqa: E501
        :rtype: RoomCompensationEnabled
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        # type: (RoomCompensationEnabled) -> None
        """Sets the enabled of this RoomCompensationInfo.


        :param enabled: The enabled of this RoomCompensationInfo.  # noqa: E501
        :type enabled: RoomCompensationEnabled
        :rtype: None
        """

        self._enabled = enabled

    @property
    def last_result(self):
        # type: () -> RoomCompensationResult
        """Gets the last_result of this RoomCompensationInfo.  # noqa: E501


        :return: The last_result of this RoomCompensationInfo.  # noqa: E501
        :rtype: RoomCompensationResult
        """
        return self._last_result

    @last_result.setter
    def last_result(self, last_result):
        # type: (RoomCompensationResult) -> None
        """Sets the last_result of this RoomCompensationInfo.


        :param last_result: The last_result of this RoomCompensationInfo.  # noqa: E501
        :type last_result: RoomCompensationResult
        :rtype: None
        """

        self._last_result = last_result

    @property
    def last_run(self):
        # type: () -> RoomCompensationState
        """Gets the last_run of this RoomCompensationInfo.  # noqa: E501


        :return: The last_run of this RoomCompensationInfo.  # noqa: E501
        :rtype: RoomCompensationState
        """
        return self._last_run

    @last_run.setter
    def last_run(self, last_run):
        # type: (RoomCompensationState) -> None
        """Sets the last_run of this RoomCompensationInfo.


        :param last_run: The last_run of this RoomCompensationInfo.  # noqa: E501
        :type last_run: RoomCompensationState
        :rtype: None
        """

        self._last_run = last_run

    @property
    def type(self):
        # type: () -> RoomCompensationType
        """Gets the type of this RoomCompensationInfo.  # noqa: E501


        :return: The type of this RoomCompensationInfo.  # noqa: E501
        :rtype: RoomCompensationType
        """
        return self._type

    @type.setter
    def type(self, type):
        # type: (RoomCompensationType) -> None
        """Sets the type of this RoomCompensationInfo.


        :param type: The type of this RoomCompensationInfo.  # noqa: E501
        :type type: RoomCompensationType
        :rtype: None
        """

        self._type = type

    @property
    def version(self):
        # type: () -> RoomCompensationVersion
        """Gets the version of this RoomCompensationInfo.  # noqa: E501


        :return: The version of this RoomCompensationInfo.  # noqa: E501
        :rtype: RoomCompensationVersion
        """
        return self._version

    @version.setter
    def version(self, version):
        # type: (RoomCompensationVersion) -> None
        """Sets the version of this RoomCompensationInfo.


        :param version: The version of this RoomCompensationInfo.  # noqa: E501
        :type version: RoomCompensationVersion
        :rtype: None
        """

        self._version = version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RoomCompensationInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RoomCompensationInfo):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import mozart_api
from mozart_api.models.listening_mode_features import (
    ListeningModeFeatures,
)  # noqa: E501
from mozart_api.rest import ApiException


class TestListeningModeFeatures(unittest.TestCase):
    """ListeningModeFeatures unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ListeningModeFeatures
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # model = mozart_api.models.listening_mode_features.ListeningModeFeatures()  # noqa: E501
        if include_optional:
            return ListeningModeFeatures(
                ambience=mozart_api.models.ambience.Ambience(
                    value=1.337,
                ),
                balance=mozart_api.models.balance.Balance(
                    value=1.337,
                ),
                bass_management=mozart_api.models.bass_management.BassManagement(
                    value="on",
                ),
                compression=mozart_api.models.compression.Compression(
                    value="off",
                ),
                directivity=mozart_api.models.directivity.Directivity(
                    value="front",
                ),
                fader=mozart_api.models.fader.Fader(
                    value=1.337,
                ),
                room_compensation=mozart_api.models.room_compensation.RoomCompensation(
                    value=["0"],
                ),
                spatial_envelopment=mozart_api.models.spatial_envelopment.SpatialEnvelopment(
                    value=1.337,
                ),
                spatial_height=mozart_api.models.spatial_height.SpatialHeight(
                    value=1.337,
                ),
                spatial_processing=mozart_api.models.spatial_processing.SpatialProcessing(
                    value="direct",
                ),
                spatial_surround=mozart_api.models.spatial_surround.SpatialSurround(
                    value=1.337,
                ),
                spatial_width=mozart_api.models.spatial_width.SpatialWidth(
                    value=1.337,
                ),
                speech_enhance=mozart_api.models.speech_enhance.SpeechEnhance(
                    value=1.337,
                ),
                tone_touch=mozart_api.models.tone_touch.ToneTouch(
                    x=mozart_api.models.tone_touch_type.ToneTouchType(
                        value=1.337,
                    ),
                    y=mozart_api.models.tone_touch_type.ToneTouchType(
                        value=1.337,
                    ),
                ),
            )
        else:
            return ListeningModeFeatures()

    def testListeningModeFeatures(self):
        """Test ListeningModeFeatures"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from datetime import datetime
from typing import List, Dict, Literal, Optional

from mozart_api.models.room_compensation_response import RoomCompensationResponse
from mozart_api.models.speaker_group import SpeakerGroup

from mozart_api.configuration import Configuration


class RoomCompensationResult(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "compensation": "list[RoomCompensationResponse]",
        "measured_response": "list[RoomCompensationResponse]",
        "placement": "str",
        "reference_response": "list[RoomCompensationResponse]",
        "speaker_group_suggestion": "SpeakerGroup",
        "time_stamp": "datetime",
    }

    attribute_map = {
        "compensation": "compensation",
        "measured_response": "measuredResponse",
        "placement": "placement",
        "reference_response": "referenceResponse",
        "speaker_group_suggestion": "speakerGroupSuggestion",
        "time_stamp": "timeStamp",
    }

    def __init__(
        self,
        compensation: Optional[List[RoomCompensationResponse]] = None,
        measured_response: Optional[List[RoomCompensationResponse]] = None,
        placement: Optional["RoomCompensationResult.LTypePlacement"] = None,
        reference_response: Optional[List[RoomCompensationResponse]] = None,
        speaker_group_suggestion: Optional[SpeakerGroup] = None,
        time_stamp: Optional[datetime] = None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """RoomCompensationResult - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._compensation = None
        self._measured_response = None
        self._placement = None
        self._reference_response = None
        self._speaker_group_suggestion = None
        self._time_stamp = None
        self.discriminator = None

        if compensation is not None:
            self.compensation = compensation
        if measured_response is not None:
            self.measured_response = measured_response
        if placement is not None:
            self.placement = placement
        if reference_response is not None:
            self.reference_response = reference_response
        if speaker_group_suggestion is not None:
            self.speaker_group_suggestion = speaker_group_suggestion
        if time_stamp is not None:
            self.time_stamp = time_stamp

    @property
    def compensation(self):
        # type: () -> List[RoomCompensationResponse]
        """Gets the compensation of this RoomCompensationResult.  # noqa: E501


        :return: The compensation of this RoomCompensationResult.  # noqa: E501
        :rtype: List[RoomCompensationResponse]
        """
        return self._compensation

    @compensation.setter
    def compensation(self, compensation):
        # type: (list[RoomCompensationResponse]) -> None
        """Sets the compensation of this RoomCompensationResult.


        :param compensation: The compensation of this RoomCompensationResult.  # noqa: E501
        :type compensation: list[RoomCompensationResponse]
        :rtype: None
        """

        self._compensation = compensation

    @property
    def measured_response(self):
        # type: () -> List[RoomCompensationResponse]
        """Gets the measured_response of this RoomCompensationResult.  # noqa: E501


        :return: The measured_response of this RoomCompensationResult.  # noqa: E501
        :rtype: List[RoomCompensationResponse]
        """
        return self._measured_response

    @measured_response.setter
    def measured_response(self, measured_response):
        # type: (list[RoomCompensationResponse]) -> None
        """Sets the measured_response of this RoomCompensationResult.


        :param measured_response: The measured_response of this RoomCompensationResult.  # noqa: E501
        :type measured_response: list[RoomCompensationResponse]
        :rtype: None
        """

        self._measured_response = measured_response

    LTypePlacement = Literal["free", "nearWall", "unknown"]

    @property
    def placement(self):
        # type: () -> 'RoomCompensationResult.LTypePlacement'
        """Gets the placement of this RoomCompensationResult.  # noqa: E501


        :return: The placement of this RoomCompensationResult.  # noqa: E501
        :rtype: 'RoomCompensationResult.LTypePlacement'
        """
        return self._placement

    @placement.setter
    def placement(self, placement):
        # type: ('RoomCompensationResult.LTypePlacement') -> None
        """Sets the placement of this RoomCompensationResult.


        :param placement: The placement of this RoomCompensationResult.  # noqa: E501
        :type placement: 'RoomCompensationResult.LTypePlacement'
        :rtype: None
        """
        allowed_values = ["free", "nearWall", "unknown"]  # noqa: E501
        if (
            self.local_vars_configuration.client_side_validation
            and placement not in allowed_values
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `placement` ({0}), must be one of {1}".format(  # noqa: E501
                    placement, allowed_values
                )
            )

        self._placement = placement

    @property
    def reference_response(self):
        # type: () -> List[RoomCompensationResponse]
        """Gets the reference_response of this RoomCompensationResult.  # noqa: E501


        :return: The reference_response of this RoomCompensationResult.  # noqa: E501
        :rtype: List[RoomCompensationResponse]
        """
        return self._reference_response

    @reference_response.setter
    def reference_response(self, reference_response):
        # type: (list[RoomCompensationResponse]) -> None
        """Sets the reference_response of this RoomCompensationResult.


        :param reference_response: The reference_response of this RoomCompensationResult.  # noqa: E501
        :type reference_response: list[RoomCompensationResponse]
        :rtype: None
        """

        self._reference_response = reference_response

    @property
    def speaker_group_suggestion(self):
        # type: () -> SpeakerGroup
        """Gets the speaker_group_suggestion of this RoomCompensationResult.  # noqa: E501


        :return: The speaker_group_suggestion of this RoomCompensationResult.  # noqa: E501
        :rtype: SpeakerGroup
        """
        return self._speaker_group_suggestion

    @speaker_group_suggestion.setter
    def speaker_group_suggestion(self, speaker_group_suggestion):
        # type: (SpeakerGroup) -> None
        """Sets the speaker_group_suggestion of this RoomCompensationResult.


        :param speaker_group_suggestion: The speaker_group_suggestion of this RoomCompensationResult.  # noqa: E501
        :type speaker_group_suggestion: SpeakerGroup
        :rtype: None
        """

        self._speaker_group_suggestion = speaker_group_suggestion

    @property
    def time_stamp(self):
        # type: () -> datetime
        """Gets the time_stamp of this RoomCompensationResult.  # noqa: E501


        :return: The time_stamp of this RoomCompensationResult.  # noqa: E501
        :rtype: datetime
        """
        return self._time_stamp

    @time_stamp.setter
    def time_stamp(self, time_stamp):
        # type: (datetime) -> None
        """Sets the time_stamp of this RoomCompensationResult.


        :param time_stamp: The time_stamp of this RoomCompensationResult.  # noqa: E501
        :type time_stamp: datetime
        :rtype: None
        """

        self._time_stamp = time_stamp

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RoomCompensationResult):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RoomCompensationResult):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from datetime import datetime
from typing import List, Dict, Literal, Optional

from mozart_api.models.beolink_leader import BeolinkLeader
from mozart_api.models.art import Art

from mozart_api.configuration import Configuration


class PlaybackContentMetadata(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "album_name": "str",
        "art": "list[Art]",
        "artist_name": "str",
        "bitdepth": "int",
        "bitrate": "int",
        "container_name": "str",
        "encoding": "str",
        "genre": "str",
        "id": "int",
        "input_channel_processing": "str",
        "input_channels": "str",
        "organization": "str",
        "output_channel_processing": "str",
        "output_channels": "str",
        "queue_id": "str",
        "remote_leader": "BeolinkLeader",
        "remote_source": "str",
        "samplerate": "int",
        "source": "str",
        "source_internal_id": "str",
        "title": "str",
        "total_duration": "int",
        "total_duration_seconds": "int",
        "track": "int",
        "track_count": "int",
        "uri": "str",
    }

    attribute_map = {
        "album_name": "albumName",
        "art": "art",
        "artist_name": "artistName",
        "bitdepth": "bitdepth",
        "bitrate": "bitrate",
        "container_name": "containerName",
        "encoding": "encoding",
        "genre": "genre",
        "id": "id",
        "input_channel_processing": "inputChannelProcessing",
        "input_channels": "inputChannels",
        "organization": "organization",
        "output_channel_processing": "outputChannelProcessing",
        "output_channels": "outputChannels",
        "queue_id": "queueId",
        "remote_leader": "remoteLeader",
        "remote_source": "remoteSource",
        "samplerate": "samplerate",
        "source": "source",
        "source_internal_id": "sourceInternalId",
        "title": "title",
        "total_duration": "totalDuration",
        "total_duration_seconds": "totalDurationSeconds",
        "track": "track",
        "track_count": "trackCount",
        "uri": "uri",
    }

    def __init__(
        self,
        album_name: Optional[str] = None,
        art: Optional[List[Art]] = None,
        artist_name: Optional[str] = None,
        bitdepth: Optional[int] = None,
        bitrate: Optional[int] = None,
        container_name: Optional[str] = None,
        encoding: Optional["PlaybackContentMetadata.LTypeEncoding"] = None,
        genre: Optional[str] = None,
        id: Optional[int] = None,
        input_channel_processing: Optional[str] = None,
        input_channels: Optional[str] = None,
        organization: Optional[str] = None,
        output_channel_processing: Optional[str] = None,
        output_channels: Optional[str] = None,
        queue_id: Optional[str] = None,
        remote_leader: Optional[BeolinkLeader] = None,
        remote_source: Optional[str] = None,
        samplerate: Optional[int] = None,
        source: Optional[str] = None,
        source_internal_id: Optional[str] = None,
        title: Optional[str] = None,
        total_duration: Optional[int] = None,
        total_duration_seconds: Optional[int] = None,
        track: Optional[int] = None,
        track_count: Optional[int] = None,
        uri: Optional[str] = None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """PlaybackContentMetadata - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._album_name = None
        self._art = None
        self._artist_name = None
        self._bitdepth = None
        self._bitrate = None
        self._container_name = None
        self._encoding = None
        self._genre = None
        self._id = None
        self._input_channel_processing = None
        self._input_channels = None
        self._organization = None
        self._output_channel_processing = None
        self._output_channels = None
        self._queue_id = None
        self._remote_leader = None
        self._remote_source = None
        self._samplerate = None
        self._source = None
        self._source_internal_id = None
        self._title = None
        self._total_duration = None
        self._total_duration_seconds = None
        self._track = None
        self._track_count = None
        self._uri = None
        self.discriminator = None

        if album_name is not None:
            self.album_name = album_name
        if art is not None:
            self.art = art
        if artist_name is not None:
            self.artist_name = artist_name
        if bitdepth is not None:
            self.bitdepth = bitdepth
        if bitrate is not None:
            self.bitrate = bitrate
        if container_name is not None:
            self.container_name = container_name
        if encoding is not None:
            self.encoding = encoding
        if genre is not None:
            self.genre = genre
        if id is not None:
            self.id = id
        self.input_channel_processing = input_channel_processing
        self.input_channels = input_channels
        if organization is not None:
            self.organization = organization
        self.output_channel_processing = output_channel_processing
        self.output_channels = output_channels
        if queue_id is not None:
            self.queue_id = queue_id
        if remote_leader is not None:
            self.remote_leader = remote_leader
        self.remote_source = remote_source
        if samplerate is not None:
            self.samplerate = samplerate
        if source is not None:
            self.source = source
        if source_internal_id is not None:
            self.source_internal_id = source_internal_id
        if title is not None:
            self.title = title
        self.total_duration = total_duration
        self.total_duration_seconds = total_duration_seconds
        if track is not None:
            self.track = track
        if track_count is not None:
            self.track_count = track_count
        if uri is not None:
            self.uri = uri

    @property
    def album_name(self):
        # type: () -> str
        """Gets the album_name of this PlaybackContentMetadata.  # noqa: E501


        :return: The album_name of this PlaybackContentMetadata.  # noqa: E501
        :rtype: str
        """
        return self._album_name

    @album_name.setter
    def album_name(self, album_name):
        # type: (str) -> None
        """Sets the album_name of this PlaybackContentMetadata.


        :param album_name: The album_name of this PlaybackContentMetadata.  # noqa: E501
        :type album_name: str
        :rtype: None
        """

        self._album_name = album_name

    @property
    def art(self):
        # type: () -> List[Art]
        """Gets the art of this PlaybackContentMetadata.  # noqa: E501


        :return: The art of this PlaybackContentMetadata.  # noqa: E501
        :rtype: List[Art]
        """
        return self._art

    @art.setter
    def art(self, art):
        # type: (list[Art]) -> None
        """Sets the art of this PlaybackContentMetadata.


        :param art: The art of this PlaybackContentMetadata.  # noqa: E501
        :type art: list[Art]
        :rtype: None
        """

        self._art = art

    @property
    def artist_name(self):
        # type: () -> str
        """Gets the artist_name of this PlaybackContentMetadata.  # noqa: E501


        :return: The artist_name of this PlaybackContentMetadata.  # noqa: E501
        :rtype: str
        """
        return self._artist_name

    @artist_name.setter
    def artist_name(self, artist_name):
        # type: (str) -> None
        """Sets the artist_name of this PlaybackContentMetadata.


        :param artist_name: The artist_name of this PlaybackContentMetadata.  # noqa: E501
        :type artist_name: str
        :rtype: None
        """

        self._artist_name = artist_name

    @property
    def bitdepth(self):
        # type: () -> int
        """Gets the bitdepth of this PlaybackContentMetadata.  # noqa: E501


        :return: The bitdepth of this PlaybackContentMetadata.  # noqa: E501
        :rtype: int
        """
        return self._bitdepth

    @bitdepth.setter
    def bitdepth(self, bitdepth):
        # type: (int) -> None
        """Sets the bitdepth of this PlaybackContentMetadata.


        :param bitdepth: The bitdepth of this PlaybackContentMetadata.  # noqa: E501
        :type bitdepth: int
        :rtype: None
        """

        self._bitdepth = bitdepth

    @property
    def bitrate(self):
        # type: () -> int
        """Gets the bitrate of this PlaybackContentMetadata.  # noqa: E501


        :return: The bitrate of this PlaybackContentMetadata.  # noqa: E501
        :rtype: int
        """
        return self._bitrate

    @bitrate.setter
    def bitrate(self, bitrate):
        # type: (int) -> None
        """Sets the bitrate of this PlaybackContentMetadata.


        :param bitrate: The bitrate of this PlaybackContentMetadata.  # noqa: E501
        :type bitrate: int
        :rtype: None
        """

        self._bitrate = bitrate

    @property
    def container_name(self):
        # type: () -> str
        """Gets the container_name of this PlaybackContentMetadata.  # noqa: E501


        :return: The container_name of this PlaybackContentMetadata.  # noqa: E501
        :rtype: str
        """
        return self._container_name

    @container_name.setter
    def container_name(self, container_name):
        # type: (str) -> None
        """Sets the container_name of this PlaybackContentMetadata.


        :param container_name: The container_name of this PlaybackContentMetadata.  # noqa: E501
        :type container_name: str
        :rtype: None
        """

        self._container_name = container_name

    LTypeEncoding = Literal[
        "pcm",
        "wav",
        "mp3",
        "oggvorbis",
        "aac",
        "flac",
        "sbc",
        "alac",
        "opus",
        "DolbyDigital",
        "DolbyDigitalPlus",
        "DolbyTrueHD",
        "unknown",
    ]

    @property
    def encoding(self):
        # type: () -> 'PlaybackContentMetadata.LTypeEncoding'
        """Gets the encoding of this PlaybackContentMetadata.  # noqa: E501


        :return: The encoding of this PlaybackContentMetadata.  # noqa: E501
        :rtype: 'PlaybackContentMetadata.LTypeEncoding'
        """
        return self._encoding

    @encoding.setter
    def encoding(self, encoding):
        # type: ('PlaybackContentMetadata.LTypeEncoding') -> None
        """Sets the encoding of this PlaybackContentMetadata.


        :param encoding: The encoding of this PlaybackContentMetadata.  # noqa: E501
        :type encoding: 'PlaybackContentMetadata.LTypeEncoding'
        :rtype: None
        """
        allowed_values = [
            "pcm",
            "wav",
            "mp3",
            "oggvorbis",
            "aac",
            "flac",
            "sbc",
            "alac",
            "opus",
            "DolbyDigital",
            "DolbyDigitalPlus",
            "DolbyTrueHD",
            "unknown",
        ]  # noqa: E501
        if (
            self.local_vars_configuration.client_side_validation
            and encoding not in allowed_values
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `encoding` ({0}), must be one of {1}".format(  # noqa: E501
                    encoding, allowed_values
                )
            )

        self._encoding = encoding

    @property
    def genre(self):
        # type: () -> str
        """Gets the genre of this PlaybackContentMetadata.  # noqa: E501


        :return: The genre of this PlaybackContentMetadata.  # noqa: E501
        :rtype: str
        """
        return self._genre

    @genre.setter
    def genre(self, genre):
        # type: (str) -> None
        """Sets the genre of this PlaybackContentMetadata.


        :param genre: The genre of this PlaybackContentMetadata.  # noqa: E501
        :type genre: str
        :rtype: None
        """

        self._genre = genre

    @property
    def id(self):
        # type: () -> int
        """Gets the id of this PlaybackContentMetadata.  # noqa: E501


        :return: The id of this PlaybackContentMetadata.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        # type: (int) -> None
        """Sets the id of this PlaybackContentMetadata.


        :param id: The id of this PlaybackContentMetadata.  # noqa: E501
        :type id: int
        :rtype: None
        """

        self._id = id

    @property
    def input_channel_processing(self):
        # type: () -> str
        """Gets the input_channel_processing of this PlaybackContentMetadata.  # noqa: E501

        Input processing/decoding on top of the base codec indicated in encoding. E.g. Dolby Atmos on top of Dolby TrueHD or Dolby Surround on top of PCM. For Dolby, this value has priority over encoding, meaning that if inputChannelProcessing has a value, it must be indicated in the app, and optionally the encoding value can be indicated as well. If inputChannelProcessing does not have value the encoding value must be indicated.   # noqa: E501

        :return: The input_channel_processing of this PlaybackContentMetadata.  # noqa: E501
        :rtype: str
        """
        return self._input_channel_processing

    @input_channel_processing.setter
    def input_channel_processing(self, input_channel_processing):
        # type: (str) -> None
        """Sets the input_channel_processing of this PlaybackContentMetadata.

        Input processing/decoding on top of the base codec indicated in encoding. E.g. Dolby Atmos on top of Dolby TrueHD or Dolby Surround on top of PCM. For Dolby, this value has priority over encoding, meaning that if inputChannelProcessing has a value, it must be indicated in the app, and optionally the encoding value can be indicated as well. If inputChannelProcessing does not have value the encoding value must be indicated.   # noqa: E501

        :param input_channel_processing: The input_channel_processing of this PlaybackContentMetadata.  # noqa: E501
        :type input_channel_processing: str
        :rtype: None
        """
        allowed_values = [None, "dolbySurround", "dolbyAtmos"]  # noqa: E501
        if (
            self.local_vars_configuration.client_side_validation
            and input_channel_processing not in allowed_values
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `input_channel_processing` ({0}), must be one of {1}".format(  # noqa: E501
                    input_channel_processing, allowed_values
                )
            )

        self._input_channel_processing = input_channel_processing

    @property
    def input_channels(self):
        # type: () -> str
        """Gets the input_channels of this PlaybackContentMetadata.  # noqa: E501

        e.g. 5.1  # noqa: E501

        :return: The input_channels of this PlaybackContentMetadata.  # noqa: E501
        :rtype: str
        """
        return self._input_channels

    @input_channels.setter
    def input_channels(self, input_channels):
        # type: (str) -> None
        """Sets the input_channels of this PlaybackContentMetadata.

        e.g. 5.1  # noqa: E501

        :param input_channels: The input_channels of this PlaybackContentMetadata.  # noqa: E501
        :type input_channels: str
        :rtype: None
        """

        self._input_channels = input_channels

    @property
    def organization(self):
        # type: () -> str
        """Gets the organization of this PlaybackContentMetadata.  # noqa: E501

        This can be filled by gstreamers GST_TAG_ORGANIZATION. Mozart can also fill this with netradio station name like \"P3\" and TV content like \"Netflix\". This is needed so it's possible to show who the provider is for the playing audio track/content.   # noqa: E501

        :return: The organization of this PlaybackContentMetadata.  # noqa: E501
        :rtype: str
        """
        return self._organization

    @organization.setter
    def organization(self, organization):
        # type: (str) -> None
        """Sets the organization of this PlaybackContentMetadata.

        This can be filled by gstreamers GST_TAG_ORGANIZATION. Mozart can also fill this with netradio station name like \"P3\" and TV content like \"Netflix\". This is needed so it's possible to show who the provider is for the playing audio track/content.   # noqa: E501

        :param organization: The organization of this PlaybackContentMetadata.  # noqa: E501
        :type organization: str
        :rtype: None
        """

        self._organization = organization

    @property
    def output_channel_processing(self):
        # type: () -> str
        """Gets the output_channel_processing of this PlaybackContentMetadata.  # noqa: E501

        e.g. downmix  # noqa: E501

        :return: The output_channel_processing of this PlaybackContentMetadata.  # noqa: E501
        :rtype: str
        """
        return self._output_channel_processing

    @output_channel_processing.setter
    def output_channel_processing(self, output_channel_processing):
        # type: (str) -> None
        """Sets the output_channel_processing of this PlaybackContentMetadata.

        e.g. downmix  # noqa: E501

        :param output_channel_processing: The output_channel_processing of this PlaybackContentMetadata.  # noqa: E501
        :type output_channel_processing: str
        :rtype: None
        """
        allowed_values = [None, "Direct", "Downmix", "TrueImage"]  # noqa: E501
        if (
            self.local_vars_configuration.client_side_validation
            and output_channel_processing not in allowed_values
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `output_channel_processing` ({0}), must be one of {1}".format(  # noqa: E501
                    output_channel_processing, allowed_values
                )
            )

        self._output_channel_processing = output_channel_processing

    @property
    def output_channels(self):
        # type: () -> str
        """Gets the output_channels of this PlaybackContentMetadata.  # noqa: E501

        e.g. 7.1  # noqa: E501

        :return: The output_channels of this PlaybackContentMetadata.  # noqa: E501
        :rtype: str
        """
        return self._output_channels

    @output_channels.setter
    def output_channels(self, output_channels):
        # type: (str) -> None
        """Sets the output_channels of this PlaybackContentMetadata.

        e.g. 7.1  # noqa: E501

        :param output_channels: The output_channels of this PlaybackContentMetadata.  # noqa: E501
        :type output_channels: str
        :rtype: None
        """

        self._output_channels = output_channels

    @property
    def queue_id(self):
        # type: () -> str
        """Gets the queue_id of this PlaybackContentMetadata.  # noqa: E501


        :return: The queue_id of this PlaybackContentMetadata.  # noqa: E501
        :rtype: str
        """
        return self._queue_id

    @queue_id.setter
    def queue_id(self, queue_id):
        # type: (str) -> None
        """Sets the queue_id of this PlaybackContentMetadata.


        :param queue_id: The queue_id of this PlaybackContentMetadata.  # noqa: E501
        :type queue_id: str
        :rtype: None
        """

        self._queue_id = queue_id

    @property
    def remote_leader(self):
        # type: () -> BeolinkLeader
        """Gets the remote_leader of this PlaybackContentMetadata.  # noqa: E501


        :return: The remote_leader of this PlaybackContentMetadata.  # noqa: E501
        :rtype: BeolinkLeader
        """
        return self._remote_leader

    @remote_leader.setter
    def remote_leader(self, remote_leader):
        # type: (BeolinkLeader) -> None
        """Sets the remote_leader of this PlaybackContentMetadata.


        :param remote_leader: The remote_leader of this PlaybackContentMetadata.  # noqa: E501
        :type remote_leader: BeolinkLeader
        :rtype: None
        """

        self._remote_leader = remote_leader

    @property
    def remote_source(self):
        # type: () -> str
        """Gets the remote_source of this PlaybackContentMetadata.  # noqa: E501


        :return: The remote_source of this PlaybackContentMetadata.  # noqa: E501
        :rtype: str
        """
        return self._remote_source

    @remote_source.setter
    def remote_source(self, remote_source):
        # type: (str) -> None
        """Sets the remote_source of this PlaybackContentMetadata.


        :param remote_source: The remote_source of this PlaybackContentMetadata.  # noqa: E501
        :type remote_source: str
        :rtype: None
        """

        self._remote_source = remote_source

    @property
    def samplerate(self):
        # type: () -> int
        """Gets the samplerate of this PlaybackContentMetadata.  # noqa: E501


        :return: The samplerate of this PlaybackContentMetadata.  # noqa: E501
        :rtype: int
        """
        return self._samplerate

    @samplerate.setter
    def samplerate(self, samplerate):
        # type: (int) -> None
        """Sets the samplerate of this PlaybackContentMetadata.


        :param samplerate: The samplerate of this PlaybackContentMetadata.  # noqa: E501
        :type samplerate: int
        :rtype: None
        """

        self._samplerate = samplerate

    @property
    def source(self):
        # type: () -> str
        """Gets the source of this PlaybackContentMetadata.  # noqa: E501


        :return: The source of this PlaybackContentMetadata.  # noqa: E501
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        # type: (str) -> None
        """Sets the source of this PlaybackContentMetadata.


        :param source: The source of this PlaybackContentMetadata.  # noqa: E501
        :type source: str
        :rtype: None
        """

        self._source = source

    @property
    def source_internal_id(self):
        # type: () -> str
        """Gets the source_internal_id of this PlaybackContentMetadata.  # noqa: E501


        :return: The source_internal_id of this PlaybackContentMetadata.  # noqa: E501
        :rtype: str
        """
        return self._source_internal_id

    @source_internal_id.setter
    def source_internal_id(self, source_internal_id):
        # type: (str) -> None
        """Sets the source_internal_id of this PlaybackContentMetadata.


        :param source_internal_id: The source_internal_id of this PlaybackContentMetadata.  # noqa: E501
        :type source_internal_id: str
        :rtype: None
        """

        self._source_internal_id = source_internal_id

    @property
    def title(self):
        # type: () -> str
        """Gets the title of this PlaybackContentMetadata.  # noqa: E501


        :return: The title of this PlaybackContentMetadata.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        # type: (str) -> None
        """Sets the title of this PlaybackContentMetadata.


        :param title: The title of this PlaybackContentMetadata.  # noqa: E501
        :type title: str
        :rtype: None
        """

        self._title = title

    @property
    def total_duration(self):
        # type: () -> int
        """Gets the total_duration of this PlaybackContentMetadata.  # noqa: E501

        to be removed once all devices and apps are updated  # noqa: E501

        :return: The total_duration of this PlaybackContentMetadata.  # noqa: E501
        :rtype: int
        """
        return self._total_duration

    @total_duration.setter
    def total_duration(self, total_duration):
        # type: (int) -> None
        """Sets the total_duration of this PlaybackContentMetadata.

        to be removed once all devices and apps are updated  # noqa: E501

        :param total_duration: The total_duration of this PlaybackContentMetadata.  # noqa: E501
        :type total_duration: int
        :rtype: None
        """

        self._total_duration = total_duration

    @property
    def total_duration_seconds(self):
        # type: () -> int
        """Gets the total_duration_seconds of this PlaybackContentMetadata.  # noqa: E501


        :return: The total_duration_seconds of this PlaybackContentMetadata.  # noqa: E501
        :rtype: int
        """
        return self._total_duration_seconds

    @total_duration_seconds.setter
    def total_duration_seconds(self, total_duration_seconds):
        # type: (int) -> None
        """Sets the total_duration_seconds of this PlaybackContentMetadata.


        :param total_duration_seconds: The total_duration_seconds of this PlaybackContentMetadata.  # noqa: E501
        :type total_duration_seconds: int
        :rtype: None
        """

        self._total_duration_seconds = total_duration_seconds

    @property
    def track(self):
        # type: () -> int
        """Gets the track of this PlaybackContentMetadata.  # noqa: E501


        :return: The track of this PlaybackContentMetadata.  # noqa: E501
        :rtype: int
        """
        return self._track

    @track.setter
    def track(self, track):
        # type: (int) -> None
        """Sets the track of this PlaybackContentMetadata.


        :param track: The track of this PlaybackContentMetadata.  # noqa: E501
        :type track: int
        :rtype: None
        """

        self._track = track

    @property
    def track_count(self):
        # type: () -> int
        """Gets the track_count of this PlaybackContentMetadata.  # noqa: E501


        :return: The track_count of this PlaybackContentMetadata.  # noqa: E501
        :rtype: int
        """
        return self._track_count

    @track_count.setter
    def track_count(self, track_count):
        # type: (int) -> None
        """Sets the track_count of this PlaybackContentMetadata.


        :param track_count: The track_count of this PlaybackContentMetadata.  # noqa: E501
        :type track_count: int
        :rtype: None
        """

        self._track_count = track_count

    @property
    def uri(self):
        # type: () -> str
        """Gets the uri of this PlaybackContentMetadata.  # noqa: E501


        :return: The uri of this PlaybackContentMetadata.  # noqa: E501
        :rtype: str
        """
        return self._uri

    @uri.setter
    def uri(self, uri):
        # type: (str) -> None
        """Sets the uri of this PlaybackContentMetadata.


        :param uri: The uri of this PlaybackContentMetadata.  # noqa: E501
        :type uri: str
        :rtype: None
        """

        self._uri = uri

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PlaybackContentMetadata):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PlaybackContentMetadata):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import mozart_api
from mozart_api.models.sound_settings import SoundSettings  # noqa: E501
from mozart_api.rest import ApiException


class TestSoundSettings(unittest.TestCase):
    """SoundSettings unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test SoundSettings
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # model = mozart_api.models.sound_settings.SoundSettings()  # noqa: E501
        if include_optional:
            return SoundSettings(
                adjustments=mozart_api.models.sound_adjustments.SoundAdjustments(
                    ambience=1.337,
                    bass=56,
                    directivity="0",
                    eco_mode=True,
                    fadein=True,
                    loudness=True,
                    treble=56,
                ),
                room_compensation=mozart_api.models.room_compensation_info.RoomCompensationInfo(
                    debug=mozart_api.models.room_compensation_debug.RoomCompensationDebug(
                        value=True,
                    ),
                    enabled=mozart_api.models.room_compensation_enabled.RoomCompensationEnabled(
                        value=True,
                    ),
                    last_result=mozart_api.models.room_compensation_result.RoomCompensationResult(
                        compensation=[
                            mozart_api.models.room_compensation_response.RoomCompensationResponse(
                                frequency=56,
                                gain=1.337,
                            )
                        ],
                        measured_response=[
                            mozart_api.models.room_compensation_response.RoomCompensationResponse(
                                frequency=56,
                                gain=1.337,
                            )
                        ],
                        placement="free",
                        reference_response=[
                            mozart_api.models.room_compensation_response.RoomCompensationResponse(
                                frequency=56,
                                gain=1.337,
                            )
                        ],
                        speaker_group_suggestion=mozart_api.models.speaker_group.SpeakerGroup(
                            crossover_frequency=20,
                            enable_phase_compensation=True,
                            friendly_name="0",
                            id="0",
                            is_deleteable=True,
                            items=[
                                mozart_api.models.speaker_group_member.SpeakerGroupMember(
                                    distance=0,
                                    friendly_name="0",
                                    gain=-24,
                                    id="0",
                                    location=mozart_api.models.speaker_group_member_location.SpeakerGroupMember_location(
                                        x=56,
                                        y=56,
                                        z=56,
                                    ),
                                    redirection_level=-100,
                                    role="0",
                                    type="0",
                                )
                            ],
                            room_compensation_id="0",
                            speaker_preset=0,
                        ),
                        time_stamp=datetime.datetime.strptime(
                            "2013-10-20 19:20:30.00", "%Y-%m-%d %H:%M:%S.%f"
                        ),
                    ),
                    last_run=null,
                    type=mozart_api.models.room_compensation_type.RoomCompensationType(
                        value="simple",
                    ),
                    version=mozart_api.models.room_compensation_version.RoomCompensationVersion(
                        algorithm=0,
                        coefficients=0,
                    ),
                ),
                tone_touch=mozart_api.models.sound_tone_touch.SoundToneTouch(
                    x=1.337,
                    y=1.337,
                    z=1.337,
                ),
            )
        else:
            return SoundSettings()

    def testSoundSettings(self):
        """Test SoundSettings"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import mozart_api
from mozart_api.models.speaker_group import SpeakerGroup  # noqa: E501
from mozart_api.rest import ApiException


class TestSpeakerGroup(unittest.TestCase):
    """SpeakerGroup unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test SpeakerGroup
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # model = mozart_api.models.speaker_group.SpeakerGroup()  # noqa: E501
        if include_optional:
            return SpeakerGroup(
                crossover_frequency=20,
                enable_phase_compensation=True,
                friendly_name="0",
                id="0",
                is_deleteable=True,
                items=[
                    mozart_api.models.speaker_group_member.SpeakerGroupMember(
                        distance=0,
                        friendly_name="0",
                        gain=-24,
                        id="0",
                        location=mozart_api.models.speaker_group_member_location.SpeakerGroupMember_location(
                            x=56,
                            y=56,
                            z=56,
                        ),
                        redirection_level=-100,
                        role="0",
                        type="0",
                    )
                ],
                room_compensation_id="0",
                speaker_preset=0,
            )
        else:
            return SpeakerGroup()

    def testSpeakerGroup(self):
        """Test SpeakerGroup"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
